package com.fs.company.controller.live;

import java.util.List;

import com.fs.live.param.LiveStudentDataQueryParam;
import com.github.pagehelper.PageHelper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.live.domain.LiveStudentData;
import com.fs.live.service.ILiveStudentDataService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 直播间学员数据Controller
 * 
 * @author fs
 * @date 2025-03-11
 */
@RestController
@RequestMapping("/live/studentData")
public class LiveStudentDataController extends BaseController
{
    @Autowired
    private ILiveStudentDataService liveStudentDataService;

    /**
     * 查询直播间学员数据列表
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:list')")
    @GetMapping("/list")
    public TableDataInfo list(LiveStudentData liveStudentData)
    {
        startPage();
        List<LiveStudentData> list = liveStudentDataService.selectLiveStudentDataList(liveStudentData);
        return getDataTable(list);
    }

    /**
     * 导出直播间学员数据列表
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:export')")
    @Log(title = "直播间学员数据", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveStudentData liveStudentData)
    {
        List<LiveStudentData> list = liveStudentDataService.selectLiveStudentDataList(liveStudentData);
        ExcelUtil<LiveStudentData> util = new ExcelUtil<LiveStudentData>(LiveStudentData.class);
        return util.exportExcel(list, "直播间学员数据数据");
    }

    /**
     * 获取直播间学员数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:query')")
    @GetMapping(value = "/{liveId}")
    public AjaxResult getInfo(@PathVariable("liveId") Long liveId)
    {
        return AjaxResult.success(liveStudentDataService.selectLiveStudentDataByLiveId(liveId));
    }

    /**
     * 新增直播间学员数据
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:add')")
    @Log(title = "直播间学员数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LiveStudentData liveStudentData)
    {
        return toAjax(liveStudentDataService.insertLiveStudentData(liveStudentData));
    }

    /**
     * 修改直播间学员数据
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:edit')")
    @Log(title = "直播间学员数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LiveStudentData liveStudentData)
    {
        return toAjax(liveStudentDataService.updateLiveStudentData(liveStudentData));
    }

    /**
     * 删除直播间学员数据
     */
    @PreAuthorize("@ss.hasPermi('live:studentData:remove')")
    @Log(title = "直播间学员数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{liveIds}")
    public AjaxResult remove(@PathVariable Long[] liveIds)
    {
        return toAjax(liveStudentDataService.deleteLiveStudentDataByLiveIds(liveIds));
    }

    @PreAuthorize("@ss.hasPermi('live:studentData:queryStudentData')")
    @PostMapping("/queryStudentData")
    public TableDataInfo queryStudentData(@RequestBody LiveStudentDataQueryParam param)
    {
        startPage();
        List<LiveStudentData> liveStudentData = liveStudentDataService.queryStudentData(param);
        return getDataTable(liveStudentData);
    }
}
