package com.fs.company.controller.qw;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

import com.alibaba.fastjson.JSON;
import com.fs.common.utils.ServletUtils;
import com.fs.course.mapper.FsCourseWatchLogMapper;
import com.fs.framework.security.LoginUser;
import com.fs.framework.service.TokenService;
import com.fs.qw.domain.QwExternalContact;
import com.fs.qw.domain.QwExternalContactInfo;
import com.fs.qw.mapper.QwExternalContactMapper;
import com.fs.qw.param.QwWorkTaskListParam;
import com.fs.qw.service.IQwExternalContactCrmService;
import com.fs.qw.service.IQwExternalContactService;
import com.fs.qw.vo.QwWorkTaskAllListVO;
import com.fs.qw.vo.QwWorkTaskListVO;
import com.fs.qwApi.domain.QwExternalContactRemarkResult;
import com.fs.qwApi.param.QwExternalContactRemarkParam;
import com.fs.qwApi.service.QwApiService;
import io.lettuce.core.ScriptOutputType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.qw.domain.QwWorkTask;
import com.fs.qw.service.IQwWorkTaskService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 企微任务看板Controller
 *
 * @author fs
 * @date 2025-03-25
 */
@RestController
@RequestMapping("/qw/QwWorkTask")
public class QwWorkTaskController extends BaseController
{
    @Autowired
    private IQwWorkTaskService qwWorkTaskService;
    @Autowired
    private TokenService tokenService;
    @Autowired
    private FsCourseWatchLogMapper fsCourseWatchLogMapper;
    /**
     * 查询企微任务看板列表
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:list')")
    @GetMapping("/list")
    public TableDataInfo list(QwWorkTaskListParam qwWorkTask)
    {
        startPage();
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        qwWorkTask.setCompanyId(loginUser.getCompany().getCompanyId());
        qwWorkTask.setCompanyUserId(loginUser.getUser().getUserId());
        List<QwWorkTaskListVO> list = qwWorkTaskService.selectQwWorkTaskListVO(qwWorkTask);
        System.out.println(list);
        for (QwWorkTaskListVO qwWorkTaskListVO : list) {
            qwWorkTaskListVO.setLogs(fsCourseWatchLogMapper.selectFsCourseWatchLog7DayByExtId(qwWorkTaskListVO.getExtId()));
        }
        return getDataTable(list);
    }

    @GetMapping("/glList")
    public TableDataInfo glList(QwWorkTaskListParam qwWorkTask)
    {
        startPage();
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        qwWorkTask.setCompanyId(loginUser.getCompany().getCompanyId());
        List<QwWorkTaskListVO> list = qwWorkTaskService.selectQwWorkTaskListVO(qwWorkTask);
        for (QwWorkTaskListVO qwWorkTaskListVO : list) {
            qwWorkTaskListVO.setLogs(fsCourseWatchLogMapper.selectFsCourseWatchLog7DayByExtId(qwWorkTaskListVO.getExtId()));
        }
        return getDataTable(list);
    }

    @GetMapping("/allList")
    public TableDataInfo allList(QwWorkTaskListParam qwWorkTask)
    {
        startPage();
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        qwWorkTask.setCompanyId(loginUser.getCompany().getCompanyId());
        List<QwWorkTaskAllListVO> list = qwWorkTaskService.selectQwWorkTaskAllListVO(qwWorkTask);
        System.out.println(list);
        return getDataTable(list);
    }
    /**
     * 导出企微任务看板列表
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:export')")
    @Log(title = "企微任务看板", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(QwWorkTask qwWorkTask)
    {
        List<QwWorkTask> list = qwWorkTaskService.selectQwWorkTaskList(qwWorkTask);
        ExcelUtil<QwWorkTask> util = new ExcelUtil<QwWorkTask>(QwWorkTask.class);
        return util.exportExcel(list, "企微任务看板数据");
    }

    /**
     * 获取企微任务看板详细信息
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(qwWorkTaskService.selectQwWorkTaskById(id));
    }

    /**
     * 新增企微任务看板
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:add')")
    @Log(title = "企微任务看板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QwWorkTask qwWorkTask)
    {
        return toAjax(qwWorkTaskService.insertQwWorkTask(qwWorkTask));
    }
    @Autowired
    QwApiService qwApiService;
    @Autowired
    IQwExternalContactService qwExternalContactService;
    @Autowired
    QwExternalContactMapper qwExternalContactMapper;
    /**
     * 修改企微任务看板
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:edit')")
    @Log(title = "企微任务看板处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QwWorkTask qwWorkTask)
    {
        QwWorkTask task = new QwWorkTask();
        task.setId(qwWorkTask.getId());
        task.setStatus(1);
        task.setTrackType(qwWorkTask.getTrackType());
        task.setDescription(qwWorkTask.getDescription());
        task.setUpdateTime(new Date());
        if (task.getDescription()!=null&& !task.getDescription().isEmpty()){

            QwExternalContact qwExternalContact = qwExternalContactService.selectQwExternalContactById(qwWorkTask.getExtId());
            if (qwExternalContact!=null){
                QwExternalContactRemarkParam param = new QwExternalContactRemarkParam();
                param.setUserid(qwExternalContact.getUserId());
                param.setExternal_userid(qwExternalContact.getExternalUserId());
                param.setDescription(task.getDescription());

                QwExternalContactRemarkResult qwExternalContactRemarkResult = qwApiService.externalcontactRemark(param, qwExternalContact.getCorpId());
                logger.info("QwExternalContactRemarkResult206：" + qwExternalContactRemarkResult);
                if (qwExternalContactRemarkResult.getErrcode() == 0) {
                    QwExternalContact ext = new QwExternalContact();
                    ext.setId(qwExternalContact.getId());
                    ext.setDescription(task.getDescription());
                    qwExternalContactMapper.updateQwExternalContact(ext);
                }
            }
        }
        return toAjax(qwWorkTaskService.updateQwWorkTask(task));
    }
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:edit')")
    @Log(title = "企微任务看板处理", businessType = BusinessType.UPDATE)
    @PutMapping("/edit2")
    public AjaxResult edit2(@RequestBody QwWorkTask qwWorkTask)
    {
        QwWorkTask task = new QwWorkTask();
        task.setId(qwWorkTask.getId());
        task.setStatus(1);
        task.setUpdateTime(new Date());
        task.setTrackType(2);
        return toAjax(qwWorkTaskService.updateQwWorkTask(task));
    }
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:edit')")
    @Log(title = "企微任务看板处理", businessType = BusinessType.UPDATE)
    @PutMapping("/edit3")
    public AjaxResult edit3(@RequestBody QwWorkTask qwWorkTask)
    {
        QwWorkTask task = new QwWorkTask();
        task.setId(qwWorkTask.getId());
        task.setStatus(1);
        task.setUpdateTime(new Date());
        task.setTrackType(3);
        return toAjax(qwWorkTaskService.updateQwWorkTask(task));
    }
    /**
     * 删除企微任务看板
     */
    @PreAuthorize("@ss.hasPermi('qw:QwWorkTask:remove')")
    @Log(title = "企微任务看板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(qwWorkTaskService.deleteQwWorkTaskByIds(ids));
    }
}
