package com.fs.company.service.impl;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.common.utils.DateUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.company.domain.CompanyUser;
import com.fs.company.service.ICompanyUserService;
import com.fs.qw.domain.QwExternalContact;
import com.fs.qw.service.IQwExternalContactService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanyCompanyFsuserMapper;
import com.fs.company.domain.CompanyCompanyFsuser;
import com.fs.company.service.ICompanyCompanyFsuserService;

/**
 * 销售绑定用户(一个用户绑定唯一一个销售)Service业务层处理
 *
 * @author fs
 * @date 2025-04-09
 */
@Service
public class CompanyCompanyFsuserServiceImpl extends ServiceImpl<CompanyCompanyFsuserMapper, CompanyCompanyFsuser> implements ICompanyCompanyFsuserService {
    @Autowired
    private ICompanyUserService companyUserService;
    @Autowired
    private IQwExternalContactService qwExternalContactService;

    /**
     * 查询销售绑定用户(一个用户绑定唯一一个销售)
     *
     * @param id 销售绑定用户(一个用户绑定唯一一个销售)主键
     * @return 销售绑定用户(一个用户绑定唯一一个销售)
     */
    @Override
    public CompanyCompanyFsuser selectCompanyCompanyUserById(Long id)
    {
        return baseMapper.selectCompanyCompanyUserById(id);
    }

    /**
     * 查询销售绑定用户(一个用户绑定唯一一个销售)列表
     *
     * @param companyCompanyUser 销售绑定用户(一个用户绑定唯一一个销售)
     * @return 销售绑定用户(一个用户绑定唯一一个销售)
     */
    @Override
    public List<CompanyCompanyFsuser> selectCompanyCompanyUserList(CompanyCompanyFsuser companyCompanyUser)
    {
        return baseMapper.selectCompanyCompanyUserList(companyCompanyUser);
    }

    /**
     * 新增销售绑定用户(一个用户绑定唯一一个销售)
     *
     * @param companyCompanyUser 销售绑定用户(一个用户绑定唯一一个销售)
     * @return 结果
     */
    @Override
    public int insertCompanyCompanyUser(CompanyCompanyFsuser companyCompanyUser)
    {
        companyCompanyUser.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertCompanyCompanyUser(companyCompanyUser);
    }

    /**
     * 修改销售绑定用户(一个用户绑定唯一一个销售)
     *
     * @param companyCompanyUser 销售绑定用户(一个用户绑定唯一一个销售)
     * @return 结果
     */
    @Override
    public int updateCompanyCompanyUser(CompanyCompanyFsuser companyCompanyUser)
    {
        companyCompanyUser.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateCompanyCompanyUser(companyCompanyUser);
    }

    /**
     * 批量删除销售绑定用户(一个用户绑定唯一一个销售)
     *
     * @param ids 需要删除的销售绑定用户(一个用户绑定唯一一个销售)主键
     * @return 结果
     */
    @Override
    public int deleteCompanyCompanyUserByIds(Long[] ids)
    {
        return baseMapper.deleteCompanyCompanyUserByIds(ids);
    }

    /**
     * 删除销售绑定用户(一个用户绑定唯一一个销售)信息
     *
     * @param id 销售绑定用户(一个用户绑定唯一一个销售)主键
     * @return 结果
     */
    @Override
    public int deleteCompanyCompanyUserById(Long id)
    {
        return baseMapper.deleteCompanyCompanyUserById(id);
    }

    @Override
    public R bind(Long companyUserId, String userId) {
        //查询销售
        CompanyUser companyUser = companyUserService.selectCompanyUserById(companyUserId);
        if (companyUser == null){
            return R.error("该链接不存在");
        }
        CompanyCompanyFsuser insertTemp = new CompanyCompanyFsuser();
        insertTemp.setUserId(Long.valueOf(userId));
        //查询是否绑定
        List<CompanyCompanyFsuser> list = selectCompanyCompanyUserList(insertTemp);
        if (list != null && !list.isEmpty()){
            return R.error("已存在绑定关系");
        }
        insertTemp.setCompanyUserId(companyUserId);
        insertTemp.setCompanyId(companyUser.getCompanyId());
        insertTemp.setStatus(1);
        //查询企微外部联系人
        QwExternalContact qw= qwExternalContactService.selectQwExternalContactLastByFsUserAndCompany(
                companyUserId,userId
        );
        if (qw != null){
            //企业微信关联用户
            insertTemp.setQwContactId(qw.getId());
        }
        //绑定
        return insertCompanyCompanyUser(insertTemp)>0?R.ok("绑定成功"):R.error("绑定失败");
    }

    @Override
    public R getInfoByUserId(String userId) {
        CompanyCompanyFsuser user = baseMapper.getInfoByUserId(userId);
        return R.ok().put("data",user);
    }
}
